==> ejc-ai-impl-3.0.0-20250314.114159-47-sources.jar: com/ejianc/foundation/ai/bean/ModelEntity.java <==
package com.ejianc.foundation.ai.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * AI模型表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ai_model")
public class ModelEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="title")
    private String title; // 模型名称
    @TableField(value="model_name")
    private String modelName; // 模型版本名称
    @TableField(value="platform")
    private Integer platform; // 模型所属平台（1：本地部署的大模型；2：本地纳管的大模型）
    @TableField(value="app_config")
    private String appConfig;
    @TableField(value="base_url")
    private String baseUrl;
    @TableField(value="context_window")
    private Integer contextWindow; // 上下文窗口
    @TableField(value="max_input_tokens")
    private Integer maxInputTokens; // 最大输入token数
    @TableField(value="max_output_tokens")
    private Integer maxOutputTokens; // 最大输出token数
    @TableField(value="model_state")
    private Integer modelState; // 模型状态（1：启用， 0：停用）

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getModelName() {
        return modelName;
    }

    public void setModelName(String modelName) {
        this.modelName = modelName;
    }

    public Integer getPlatform() {
        return platform;
    }

    public void setPlatform(Integer platform) {
        this.platform = platform;
    }

    public String getAppConfig() {
        return appConfig;
    }

    public void setAppConfig(String appConfig) {
        this.appConfig = appConfig;
    }

    public String getBaseUrl() {
        return baseUrl;
    }

    public void setBaseUrl(String baseUrl) {
        this.baseUrl = baseUrl;
    }

    public Integer getContextWindow() {
        return contextWindow;
    }

    public void setContextWindow(Integer contextWindow) {
        this.contextWindow = contextWindow;
    }

    public Integer getMaxInputTokens() {
        return maxInputTokens;
    }

    public void setMaxInputTokens(Integer maxInputTokens) {
        this.maxInputTokens = maxInputTokens;
    }

    public Integer getMaxOutputTokens() {
        return maxOutputTokens;
    }

    public void setMaxOutputTokens(Integer maxOutputTokens) {
        this.maxOutputTokens = maxOutputTokens;
    }

    public Integer getModelState() {
        return modelState;
    }

    public void setModelState(Integer modelState) {
        this.modelState = modelState;
    }
}

==> ejc-ai-impl-3.0.0-20250423.074155-110-sources.jar: com/ejianc/foundation/ai/bean/ModelEntity.java <==
package com.ejianc.foundation.ai.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * AI模型表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ai_model")
public class ModelEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="title")
    private String title; // 模型名称
    @TableField(value="model_name")
    private String modelName; // 模型版本名称
    @TableField(value="platform")
    private Integer platform; // 模型所属平台（1：本地部署的大模型；2：本地纳管的大模型）
    @TableField(value="app_config")
    private String appConfig;
    @TableField(value="base_url")
    private String baseUrl;
    @TableField(value="context_window")
    private Integer contextWindow; // 上下文窗口
    @TableField(value="max_input_tokens")
    private Integer maxInputTokens; // 最大输入token数
    @TableField(value="max_output_tokens")
    private Integer maxOutputTokens; // 最大输出token数
    @TableField(value="model_state")
    private Integer modelState; // 模型状态（1：启用， 0：停用）
    @TableField(value="embedding_model_flag")
    private Integer embeddingModelFlag; // 是否为embedding模型（1：是， 0：否）

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getModelName() {
        return modelName;
    }

    public void setModelName(String modelName) {
        this.modelName = modelName;
    }

    public Integer getPlatform() {
        return platform;
    }

    public void setPlatform(Integer platform) {
        this.platform = platform;
    }

    public String getAppConfig() {
        return appConfig;
    }

    public void setAppConfig(String appConfig) {
        this.appConfig = appConfig;
    }

    public String getBaseUrl() {
        return baseUrl;
    }

    public void setBaseUrl(String baseUrl) {
        this.baseUrl = baseUrl;
    }

    public Integer getContextWindow() {
        return contextWindow;
    }

    public void setContextWindow(Integer contextWindow) {
        this.contextWindow = contextWindow;
    }

    public Integer getMaxInputTokens() {
        return maxInputTokens;
    }

    public void setMaxInputTokens(Integer maxInputTokens) {
        this.maxInputTokens = maxInputTokens;
    }

    public Integer getMaxOutputTokens() {
        return maxOutputTokens;
    }

    public void setMaxOutputTokens(Integer maxOutputTokens) {
        this.maxOutputTokens = maxOutputTokens;
    }

    public Integer getModelState() {
        return modelState;
    }

    public void setModelState(Integer modelState) {
        this.modelState = modelState;
    }

    public Integer getEmbeddingModelFlag() {
        return embeddingModelFlag;
    }

    public void setEmbeddingModelFlag(Integer embeddingModelFlag) {
        this.embeddingModelFlag = embeddingModelFlag;
    }
}
